@@ -2,7 +2,7 @@ def read_env_variables():
     try:
         file = open(".env", "r")
         keys = {}
-        
+
         for line in file.readlines():
             split = line.split("=")
 
@@ -11,7 +11,7 @@ def read_env_variables():
 
             key, val = split
 
-            keys[key] = val
+            keys[key] = val[:-1]
 
         file.close()
 
