@@ -8,7 +8,7 @@ from app.utils.print import print_error
 from app.utils.validation import is_valid_key
 
 @click.command()
-@click.option("--key", prompt="Enter your OpenAI API key")
+@click.option("-k", "--key", prompt="Enter your OpenAI API key")
 def main(key=None):
     if not key:
         key = load_key()
